# houseteli_administrator

## Usage

- Add as submodule

```bash
git submodule add git@github.com:houseteli/houseteli_administrator.git houseteli_administrator
```

- Add to installed apps

```python
INSTALLED_APPS = [
    # ...
    'houseteli_administrator',
]
```

- Add urls entry

```python
urlpatterns = [
    #...
    path('', include('houseteli_administrator.urls')),
]
```

- Whitelabeling admin


```python
from houseteli_administrator import utils as admin_utils
admin_utils.set_site_id()
```